% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/features.R
\name{entropy}
\alias{entropy}
\title{Compute Shannon's entropy
Per default we normalize to a range [0,1] by dividing through log(length(p))}
\usage{
entropy(p, normalized = TRUE)
}
\arguments{
\item{p:}{Vector of probabilities
normalized:    If true, normalize to [0,1]}
}
\value{
vector
}
\description{
Compute Shannon's entropy
Per default we normalize to a range [0,1] by dividing through log(length(p))
}
\examples{
 day1 <-  c(1,10,10,10,10,10,1,5,10,5,50,10,1,10,10,10,10,10,1,5,10,5,50,10)
 day2 <-  c(10,1,1,10,10,10,1,5,1,50,5,10,10,1,1,10,10,10,1,5,1,50,5,10)
 day3 <-  c(1,1,1,10,0,0,10,50,1,5,5,10,1,1,1,10,0,0,10,50,1,5,5,10)
 day4 <-  c(1,10,1,10,10,10,1,5,10,5,5,10,1,10,1,10,10,10,1,5,10,5,5,10)
 y <- c(day1,day2,day3,day4)									# We have 4 days each with 24 measurements
 windows <- getTimeWindows(y, 3) 								# We summarize three hours to one time window
 features <- as.vector(colSums(sapply(windows,f1_high_amplitude_points, threshold=5)))	
 prob <- toProbabilityMatrix(features,4)							# With a dimension size of 4 (days), we get 8 columns
 result <- apply(prob,2, entropy)								# Each column is an entropy value
 fit <- HoltWinters(ts(result,frequency=2))							# We assume, the pattern repeats every 2 time windows (6 hours)
 fore <- forecast(fit, h=2)									# We forecast the next 2 time windows (6 hours)
 plot(fore)
}
